@@ -10,9 +10,9 @@ from pydantic import Field, SecretStr, create_model, validator
 from toucan_connectors.common import ConnectorStatus, nosql_apply_parameters_to_query
 from toucan_connectors.json_wrapper import JsonWrapper
 from toucan_connectors.mongo.mongo_translator import MongoConditionTranslator
+from toucan_connectors.pagination import build_pagination_info
 from toucan_connectors.toucan_connector import (
     DataSlice,
-    DataStats,
     ToucanConnector,
     ToucanDataSource,
     UnavailableVersion,
@@ -24,23 +24,35 @@ from toucan_connectors.toucan_connector import (
 MAX_COUNTED_ROWS = 1000001
 
 
-def _is_match_empty(match_: dict) -> bool:
-    def is_empty(elem: Any):
-        # Not matching None here, because we don't want to consider {'$match': {'col': None}} to be
-        # empty
-        if elem == {}:
-            return True
-        if isinstance(elem, dict):
-            return _is_match_empty(elem)
-        return False
+def _is_empty_match_column(elem: Any):
+    # Not matching None here, because we don't want to consider {'$match': {'col': None}} to be
+    # empty
+    if elem == {}:
+        return True
+    if isinstance(elem, dict):
+        return _is_match_empty(elem)
 
-    return all(is_empty(v) for v in match_.values())
+    return False
+
+
+def _is_match_empty(match_: dict) -> bool:
+    return all(_is_empty_match_column(v) for v in match_.values())
 
 
 def _is_match_statement(d: Any) -> bool:
     return isinstance(d, dict) and list(d.keys()) == ['$match']
 
 
+def _sanitize_match(query: dict) -> dict:
+    if _is_match_empty(query):
+        return {}
+    if '$and' in query:
+        and_condition = query['$and']
+        if isinstance(and_condition, list):
+            query['$and'] = [elem for elem in and_condition if not _is_empty_match_column(elem)]
+    return query
+
+
 def _sanitize_query_matches(query: dict | list[dict]) -> Any:
     """Transforms match operations matching nothing into match-alls.
 
@@ -49,7 +61,7 @@ def _sanitize_query_matches(query: dict | list[dict]) -> Any:
     """
     if isinstance(query, list):
         return [
-            {'$match': {}} if (_is_match_statement(q) and _is_match_empty(q)) else q for q in query
+            {'$match': _sanitize_match(q['$match'])} if _is_match_statement(q) else q for q in query
         ]
     return query
 
@@ -290,7 +302,10 @@ class MongoConnector(ToucanConnector, VersionableEngineConnector):
             except Exception:
                 pass
         return DataSlice(
-            df, stats=DataStats(total_returned_rows=total_count, total_rows=total_count)
+            df,
+            pagination_info=build_pagination_info(
+                offset=offset, limit=limit, retrieved_rows=len(df), total_rows=total_count
+            ),
         )
 
     def get_slice_with_regex(
@@ -328,7 +343,7 @@ class MongoConnector(ToucanConnector, VersionableEngineConnector):
         data_source.query.append({'$match': {'$expr': search_steps}})
         data_source.query.append({'$unset': ['_id']})
 
-        return self.get_slice(data_source, permissions, limit=limit, offset=offset)
+        return self.get_slice(data_source, permissions, limit=limit, offset=offset or 0)
 
     def get_df_with_regex(
         self,
