@@ -1,6 +1,5 @@
 import logging
 import re
-import time
 from contextlib import suppress
 from enum import Enum
 from functools import cached_property
@@ -12,11 +11,11 @@ from pydantic import Field, SecretStr, create_model, root_validator, validator
 from pydantic.types import constr
 
 from toucan_connectors.common import ConnectorStatus
+from toucan_connectors.pagination import build_pagination_info
 from toucan_connectors.redshift.utils import build_database_model_extraction_query, types_map
 from toucan_connectors.sql_query_helper import SqlQueryHelper
 from toucan_connectors.toucan_connector import (
     DataSlice,
-    DataStats,
     DiscoverableConnector,
     TableInfo,
     ToucanConnector,
@@ -50,7 +49,7 @@ ORDERED_KEYS = [
     'enable_tcp_keepalive',
 ]
 
-_LOGGER = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 class AuthenticationMethod(str, Enum):
@@ -245,20 +244,9 @@ class RedshiftConnector(ToucanConnector, DiscoverableConnector):
             prepared_query, prepared_query_parameters = SqlQueryHelper.prepare_limit_query(
                 datasource.query, datasource.parameters, offset, limit
             )
-        start = time.time()
         with self._get_connection(database=datasource.database).cursor() as cursor:
-            connection_opening_delta = time.time() - start
-            _LOGGER.info(f'Opening a connection to Redshift took {connection_opening_delta:.2f}s')
             cursor.execute(prepared_query, prepared_query_parameters)
-            query_execution_delta = time.time() - connection_opening_delta - start
-            _LOGGER.info(f'Executing the Redshift query took {query_execution_delta:.2f}s')
             result: pd.DataFrame = cursor.fetch_dataframe()
-            data_retrieval_delta = (
-                time.time() - query_execution_delta - connection_opening_delta - start
-            )
-            _LOGGER.info(
-                f'Reading the query result from Redshift query took {data_retrieval_delta:.2f}s'
-            )
             if result is None:
                 result = pd.DataFrame()
         return result
@@ -295,7 +283,12 @@ class RedshiftConnector(ToucanConnector, DiscoverableConnector):
 
         return DataSlice(
             df,
-            stats=DataStats(total_returned_rows=total_returned_rows, total_rows=total_rows),
+            pagination_info=build_pagination_info(
+                offset=offset,
+                limit=limit,
+                total_rows=total_rows,
+                retrieved_rows=total_returned_rows,
+            ),
         )
 
     @staticmethod
